@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 
@@ -40,7 +40,11 @@ public:
   Box_DB_Table();
   Box_DB_Table(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Box_DB_Table();
-    
+
+protected:
+  void handle_error(const Glib::Exception& ex);
+  void handle_error(const std::exception& ex); //TODO_port: This is probably useless now.
+
   Gtk::Window* get_app_window();
   const Gtk::Window* get_app_window() const;
 };
