@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_MODE_DATA_BOX_DATA_PORTAL_H
@@ -25,7 +25,6 @@
 
 #include "box_data_manyrecords.h"
 #include <glom/utility_widgets/layoutwidgetbase.h>
-#include <gtkmm/alignment.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/label.h>
 
@@ -121,7 +120,6 @@ protected:
   Glib::ustring get_title_singular(const Glib::ustring& locale) const;  
   
   Gtk::Frame m_Frame;
-  Gtk::Alignment m_Alignment;
   Gtk::Label m_Label;
 
   sharedptr<LayoutItem_Portal> m_portal;
