@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "cellrenderer_dblist.h"
@@ -103,20 +103,22 @@ void CellRendererDbList::repack_cells_fixed(Gtk::CellLayout* combobox)
   {
     //Get the default column, created by set_text_column():
     Gtk::CellRendererText* cell = dynamic_cast<Gtk::CellRendererText*>(combobox->get_first_cell());
+    if (cell)
+    {
+      //Unpack and repack it with expand=false instead of expand=true:
+      //We don't expand the first column, so we can align the other columns.
+      cell->reference();
+      combobox->clear();
+      combobox->pack_start(*cell, false);
+      cell->unreference();
 
-    //Unpack and repack it with expand=false instead of expand=true:
-    //We don't expand the first column, so we can align the other columns.
-    cell->reference();
-    combobox->clear();
-    combobox->pack_start(*cell, false);
-    cell->unreference();
+      //Make the renderer render the column:
+      combobox->add_attribute(*cell, "text", get_fixed_model_text_column());
 
-    //Make the renderer render the column:
-    combobox->add_attribute(*cell, "text", get_fixed_model_text_column());
+      cell->property_xalign() = 0.0f;
 
-    cell->property_xalign() = 0.0f;
-
-    m_repacked_first_cell = true; //Avoid doing this again.
+      m_repacked_first_cell = true; //Avoid doing this again.
+    }
   }
 
   //Add extra cells:
