@@ -23,6 +23,7 @@
 #include <glom/appwindow.h>
 #include <glom/mode_data/datawidget/textview.h>
 #include <glom/mode_data/datawidget/label.h>
+#include <glom/utils_ui.h>
 #include <iostream>
 
 namespace Glom
@@ -113,24 +114,26 @@ void LayoutWidgetBase::apply_formatting(Gtk::Widget& widget, const sharedptr<con
   if(!layout_item)
     return;
 
-  //Horizontal alignment:
-  const Formatting::HorizontalAlignment alignment =
-    layout_item->get_formatting_used_horizontal_alignment(true /* for details view */);
-  const float x_align = (alignment == Formatting::HORIZONTAL_ALIGNMENT_LEFT ? 0.0 : 1.0);
-  Gtk::Misc* misc = dynamic_cast<Gtk::Misc*>(widget_to_change);
-  if(misc)
-    misc->set_alignment(x_align);
-    
-  //Set justification on labels:
+  //Set justification on labels and text views:
   //Assume that people want left/right justification of multi-line text if they chose 
   //left/right alignment of the text itself.
   {
-    const Gtk::Justification justification = (alignment == Formatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::JUSTIFY_LEFT : Gtk::JUSTIFY_RIGHT);
+    const Formatting::HorizontalAlignment alignment =
+     layout_item->get_formatting_used_horizontal_alignment(true /* for details view */);
+    const Gtk::Justification justification =
+      (alignment == Formatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::JUSTIFY_LEFT : Gtk::JUSTIFY_RIGHT);
+    const Gtk::Align x_align =
+      (alignment == Formatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::ALIGN_START : Gtk::ALIGN_END);
+
     Gtk::Label* label = dynamic_cast<Gtk::Label*>(widget_to_change);
     if(label)
-    {    
+    {
+      //Note that set_justify() does nothing for single lines of text,
+      //and doesn't align the block of text itself,
+      //so we use set_xalign() to get the effect even for single lines of text.
+      //See http://www.murrayc.com/permalink/2015/03/02/gtk-aligning-justification-in-text-widgets/
       label->set_justify(justification);
-      //set_xalign() too (instead of deprecated Misc::set_alignment) is better, but isn't available until GTK+/gtkmm 3.16.
+      label->set_xalign(x_align);
     } else {
       Gtk::TextView* textview = dynamic_cast<Gtk::TextView*>(widget_to_change);
       if(textview)
@@ -156,42 +159,33 @@ void LayoutWidgetBase::apply_formatting(Gtk::Widget& widget, const sharedptr<con
   const Glib::ustring font_desc = formatting.get_text_format_font();
   if(!font_desc.empty())
   {
-    widget_to_change->override_font( Pango::FontDescription(font_desc) );
+    UiUtils::load_font_into_css_provider(*widget_to_change, font_desc);
   }
 
   
   const Glib::ustring fg = formatting.get_text_format_color_foreground();
   if(!fg.empty())
   {
-    // "text" is the text color. (Works for GtkEntry and GtkTextView, 
-    // for which override_color() doesn't seem to have any effect.
-    widget_to_change->override_color(Gdk::RGBA(fg));
-    
-    // This works for GtkLabel, for which override_color() does not.
-    widget_to_change->override_color(Gdk::RGBA(fg));
+    UiUtils::load_color_into_css_provider(*widget_to_change, fg);
   }
 
-
   const Glib::ustring bg = formatting.get_text_format_color_background();
   if(!bg.empty())
   {
     if(!labelglom && !button)
     {
-      // "base" is the background color for GtkEntry. "bg" seems to change the border:
-      widget_to_change->override_background_color(Gdk::RGBA(bg));
+      UiUtils::load_background_color_into_css_provider(*widget_to_change, bg);
     }
     //According to the gtk_widget_override_background_color() documentation, 
     //a GtkLabel can only have a background color by, for instance, placing it 
     //in a GtkEventBox. Luckily Label is actually derived from EventBox.
     else if(labelglom)
     {
-      //label->override_background_color(Gdk::RGBA("bg"));
-      labelglom->override_background_color(Gdk::RGBA(bg));
+      UiUtils::load_background_color_into_css_provider(*labelglom, bg);
     }
     else if(button)
     {
-      //button->override_background_color(Gdk::RGBA("bg"));
-      button->override_background_color(Gdk::RGBA(bg));
+      UiUtils::load_background_color_into_css_provider(*button, bg);
     }
   }
 }
