@@ -89,10 +89,7 @@ void connect_signals(Glom::CsvParser& parser)
 int main()
 {
   //Threading is always enabled starting from GLib 2.31.0:
-  //TODO: Just remove this when we can increase the glibmm version needed:
-#if !GLIB_CHECK_VERSION (2, 31, 0)
-  Glib::thread_init();
-#endif
+  //Glib::thread_init();
 
   Glib::init();
   Gio::init();
