@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
-71 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301 USA.
  */
 
@@ -85,7 +85,7 @@ static bool needs_navigation(Glom::Document& document, const Glib::ustring& tabl
   layout_item->set_full_field_details(
     document.get_field(table_name, field_name));
 
-  Glom::sharedptr<Glom::Relationship> field_used_in_relationship_to_one;
+  Glom::sharedptr<const Glom::Relationship> field_used_in_relationship_to_one;
   return Glom::DbUtils::layout_field_should_have_navigation(table_name, 
     layout_item, &document, field_used_in_relationship_to_one);
 }
