@@ -66,8 +66,8 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder_set = 
     Glom::Utils::build_sql_update_with_where_clause(table_name,
       field, value_set, where_clause);
-  const bool rows_affected = Glom::DbUtils::query_execute(builder_set);
-  if(!rows_affected)
+  const int rows_affected = Glom::DbUtils::query_execute(builder_set);
+  if(rows_affected == -1)
   {
     std::cerr << G_STRFUNC << ": Failure: UPDATE failed." << std::endl;
     return false;
@@ -125,6 +125,12 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     binary_read = &(blob->data);
   }
 
+  if(!binary_read)
+  {
+    std::cerr << G_STRFUNC << ": Failure: The value read's data was null." << std::endl;
+    return false;
+  }
+
   const GdaBinary* binary_set = gda_value_get_binary(value_set.gobj());
   if(!binary_set)
   {
